==> lusid-tr-sdk-0.5.1557.tar.gz: lusid-tr-sdk-0.5.1557/lusidtr/models/perpetual_property.py <==
# coding=utf-8
# --------------------------------------------------------------------------
# # License
#
# Copyright &copy; 2018 FINBOURNE TECHNOLOGY LTD
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PerpetualProperty(Model):
    """This is intended to be the external facing unitemporal property
    specification data type.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param key: The property key made up of the PropertyDomain, scope and name
     delimited with a '/'
     e.g. security/myscope/myproperty
    :type key: str
    :param value:
    :type value: object
    :ivar unit: The unit of the value
    :vartype unit: str
    """

    _validation = {
        'key': {'required': True},
        'value': {'required': True},
        'unit': {'readonly': True},
    }

    _attribute_map = {
        'key': {'key': 'key', 'type': 'str'},
        'value': {'key': 'value', 'type': 'object'},
        'unit': {'key': 'unit', 'type': 'str'},
    }

    def __init__(self, key, value):
        super(PerpetualProperty, self).__init__()
        self.key = key
        self.value = value
        self.unit = None

==> lusid-tr-sdk-0.9.189.tar.gz: lusid-tr-sdk-0.9.189/lusidtr/models/perpetual_property.py <==
# coding=utf-8
# --------------------------------------------------------------------------
# # License
#
# Copyright &copy; 2018 FINBOURNE TECHNOLOGY LTD
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PerpetualProperty(Model):
    """This is intended to be the external facing unitemporal property
    specification data type.

    :param key: The property key made up of the PropertyDomain, scope and name
     delimited with a '/'
     e.g. security/myscope/myproperty
    :type key: str
    :param value:
    :type value: object
    :param unit: The unit of the value
    :type unit: str
    """

    _validation = {
        'key': {'required': True},
        'value': {'required': True},
    }

    _attribute_map = {
        'key': {'key': 'key', 'type': 'str'},
        'value': {'key': 'value', 'type': 'object'},
        'unit': {'key': 'unit', 'type': 'str'},
    }

    def __init__(self, key, value, unit=None):
        super(PerpetualProperty, self).__init__()
        self.key = key
        self.value = value
        self.unit = unit
